Change of authors email address
[obnox/wireshark/wip.git] / filters.h
index bf0a000e3895f25cce6de1cba33f134251bc5a7f..41f563db8647b967ab8e35848eedd807b5a10f9b 100644 (file)
--- a/filters.h
+++ b/filters.h
@@ -1,23 +1,23 @@
 /* filters.c
  * Declarations of routines for reading and writing the filters file.
  *
- * $Id: filters.h,v 1.2 2001/01/28 09:13:07 guy Exp $
+ * $Id$
  *
- * Ethereal - Network traffic analyzer
+ * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
  *
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * Filter lists.
  */
 typedef enum {
-       CFILTER_LIST,   /* capture filter list */
-       DFILTER_LIST    /* display filter list */
+       CFILTER_LIST,           /* capture filter list - saved */
+       DFILTER_LIST,           /* display filter list - saved */
+       CFILTER_EDITED_LIST,    /* capture filter list - currently edited */
+       DFILTER_EDITED_LIST     /* display filter list - currently edited */
 } filter_list_type_t;
 
 /*
@@ -47,7 +49,7 @@ typedef struct {
  * the file we tried to read - it should be freed by our caller -
  * and "*errno_return" is set to the error.
  */
-void read_filter_list(filter_list_type_t list, char **pref_path_return,
+void read_filter_list(filter_list_type_t list_type, char **pref_path_return,
     int *errno_return);
 
 /*
@@ -59,8 +61,8 @@ GList *get_filter_list_first(filter_list_type_t list);
  * Add a new filter to the end of a list.
  * Returns a pointer to the newly-added entry.
  */
-GList *add_to_filter_list(filter_list_type_t list, char *name,
-    char *expression);
+GList *add_to_filter_list(filter_list_type_t list, const char *name,
+    const char *expression);
 
 /*
  * Remove a filter from a list.
@@ -75,5 +77,11 @@ void remove_from_filter_list(filter_list_type_t list, GList *fl_entry);
  * the file we tried to read - it should be freed by our caller -
  * and "*errno_return" is set to the error.
  */
-void save_filter_list(filter_list_type_t list, char **pref_path_return,
+void save_filter_list(filter_list_type_t list_type, char **pref_path_return,
     int *errno_return);
+
+/*
+ * Clone the filter list so it can be edited.
+ */
+void copy_filter_list(filter_list_type_t dest_type, filter_list_type_t src_type);
+